@@ -506,8 +506,6 @@ class MenuWin( object ):
         self.mainwin = MainWindow( self.button_box, self.settings, self.keybinder )
         self.mainwin.window.connect( "map-event", self.onWindowMap )
         self.mainwin.window.connect( "unmap-event", self.onWindowUnmap )
-        self.mainwin.window.connect( "enter-notify-event", self.onWindowEnter )
-        self.mainwin.window.connect( "leave-notify-event", self.onWindowLeave )
         self.mainwin.window.connect( "realize", self.onRealize )
         self.mainwin.window.connect( "size-allocate", lambda *args: self.positionMenu() )
 
@@ -536,14 +534,6 @@ class MenuWin( object ):
         self.pointerMonitor.ungrabPointer()
         return False
         
-    def onWindowEnter(self, applet, event):
-        self.pointerMonitor.ungrabPointer()
-        return False
-
-    def onWindowLeave(self, applet, event):
-        self.pointerMonitor.grabPointer()
-        return False
-        
     def onRealize( self, *args):
         self.pointerMonitor.addWindowToMonitor( self.mainwin.window.window )
         self.pointerMonitor.addWindowToMonitor( self.applet.window )
