@@ -1,12 +1,10 @@
+#!/usr/bin/env python
+
 import gi
 gi.require_version("Gtk", "2.0")
 
 from gi.repository import Gtk, Pango
-import sys
 import os
-import gobject
-import datetime
-import fcntl
 from easygsettings import EasyGSettings
 from execute import Execute
 from easyfiles import *
